==> haskell-here-1.2.14-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 here
version:              1.2.14
visibility:           public
id:                   here-1.2.14-GBoC1YCGjNU2klRXMTXcwa
key:                  here-1.2.14-GBoC1YCGjNU2klRXMTXcwa
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  7174e2a399ac792c876313cfae033b8e
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/here-1.2.14
library-dirs:         /usr/lib/ghc-9.4.8/site-local/here-1.2.14
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/here-1.2.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-here
hs-libraries:         HShere-1.2.14-GBoC1YCGjNU2klRXMTXcwa
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-GcWNIWVHiGQBjlHG1sYidx
    mtl-2.2.2 parsec-3.1.16.1 template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-here-1.2.14-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 here
version:              1.2.14
visibility:           public
id:                   here-1.2.14-Ky1ZEOn41fUArSgC2Gh2Mw
key:                  here-1.2.14-Ky1ZEOn41fUArSgC2Gh2Mw
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  4fa263cc8afa0fdd0eef10d8cd84aca0
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/here-1.2.14
library-dirs:         /usr/lib/ghc-9.4.8/site-local/here-1.2.14
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/here-1.2.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-here
hs-libraries:         HShere-1.2.14-Ky1ZEOn41fUArSgC2Gh2Mw
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-54OOuk87jxr2FwcHjoeIDa
    mtl-2.2.2 parsec-3.1.16.1 template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
